#ifndef __TRIANGLE_H__
#define __TRIANGLE_H__

/*! @brief  simple class to hold a triangle */
#include <ngl/Vector.h>
#include <ngl/ShaderManager.h>
#include <ngl/TransformStack.h>
class Triangle
{
private :
	// The triangles verticies
  ngl::Vector m_v0;
  ngl::Vector m_v1;
  ngl::Vector m_v2;
	// two edges for the triangle / ray calculation
  ngl::Vector m_edge1;
  ngl::Vector m_edge2;
	// the center of the triangle
  ngl::Vector m_center;
	// @brief the vertex normals of the triangle
	std::vector<GLfloat> m_normals;
	// @brief the vertex points of the triangle
	std::vector<GLfloat> m_points;

	// flag to indicate if tri has been intersected with ray
  bool m_hit;
	// u,v,w values for the calculation of hit point
  ngl::Real m_u;
  ngl::Real m_v;
  ngl::Real m_w;
	// the actual hit point of the tri
  ngl::Vector m_hitPoint;

public :
	// ctor
  Triangle(
            ngl::Vector _p0,
            ngl::Vector _p1,
            ngl::Vector _p2
          );
	// method to draw the tri
	void draw(
					  const std::string &_shaderName,
	          ngl::TransformStack &_transformStack
					 );
	// method to see if ray has intercepted with triangle.
  void rayTriangleIntersect(
                            ngl::Vector _rayStart,
                            ngl::Vector _rayEnd
                           );


};

#endif
