#ifndef __SPHERE_H__
#define __SPHERE_H__

#ifdef LINUX
	#include <GL/glew.h>
	#include <GL/gl.h>
#endif
#ifdef DARWIN
	#include <OpenGL/gl.h>
#endif

#include <ngl/ShaderManager.h>
#include <ngl/TransformStack.h>
#include <ngl/Vector.h>

/*! \brief a simple sphere class */
class Sphere
{
public :	
	/// @brief ctor
	/// @param pos the position of the sphere
	/// @param rad the radius of the sphere */
	Sphere(
					ngl::Vector _pos,
					ngl::Vector _dir,
					GLfloat _rad
				);
	/*! draw method*/
	void draw(
						 const std::string &_shaderName,
						 ngl::TransformStack &_transformStack

					  )const ;

	inline void setHit(){m_hit=true;}
	inline void setNotHit(){m_hit=false;}
	inline bool isHit()const {return m_hit;}
	inline ngl::Vector getPos() const {return m_pos;}
	inline ngl::Vector getNextPos() const {return m_nextPos;}
	inline GLfloat getRadius() const {return m_radius;}
	inline void setDirection(ngl::Vector _d){m_dir=_d;}
	void move();
	/// set the sphere values
	/// @param[in] _pos the position to set
	/// @param[in] _dir the direction of the sphere
	/// @param[in] _rad the radius of the sphere

	  void set(
	            ngl::Vector _pos,
	            ngl::Vector _dir,
	            GLfloat _rad
	          );
private :
	/*! the position of the sphere */
	ngl::Vector m_pos;
	/*! the radius of the sphere */
	GLfloat m_radius;
	/*! flag to indicate if the sphere has been hit by ray */
	bool m_hit;
	// the direction of the sphere
  ngl::Vector m_dir;
	// the last position of the sphere
  ngl::Vector m_lastPos;
	// the next position of the sphere
  ngl::Vector m_nextPos;


};





#endif
