#include "Sphere.h"
#include <ngl/VBOPrimitives.h>


Sphere::Sphere(
                ngl::Vector _pos,
                ngl::Vector _dir,
                GLfloat _rad)
{
  // set values from params
  m_pos=_pos;
  m_dir=_dir;
  m_radius=_rad;
	m_hit=false;
}

Sphere::Sphere()
{
	m_hit=false;
}

void Sphere::draw(
									 const std::string &_shaderName,
									 ngl::TransformStack &_transformStack
								 )const
{

	// draw wireframe if hit
	if(m_hit)
	{
		glPolygonMode(GL_FRONT_AND_BACK,GL_LINE);
	}
	else
	{
	  glPolygonMode(GL_FRONT_AND_BACK,GL_FILL);
	}


  ngl::ShaderManager *shader=ngl::ShaderManager::instance();
  // grab an instance of the primitives for drawing
  ngl::VBOPrimitives *prim=ngl::VBOPrimitives::instance();

	_transformStack.pushTransform();
	{
		_transformStack.getCurrentTransform().setPosition(m_pos);
		_transformStack.getCurrentTransform().setScale(m_radius,m_radius,m_radius);
		shader->setShaderParamFromMatrix(_shaderName,"ModelMatrix",_transformStack.getCurrAndGlobal().getMatrix());

		prim->draw("sphere");
	} // and before a pop
   _transformStack.popTransform();

glPolygonMode(GL_FRONT_AND_BACK,GL_FILL);
}



void Sphere :: set(
                    ngl::Vector _pos,
                    ngl::Vector _dir,
                    GLfloat _rad
                  )
{
  m_pos=_pos;
  m_dir=_dir;
  m_radius=_rad;
}

void Sphere::move()
{
  // store the last position
  m_lastPos=m_pos;
  // update the current position
  m_pos+=m_dir;
  // get the next position
  m_nextPos=m_pos+m_dir;
	m_hit=false;
}












